@@ -234,8 +234,13 @@ def alerts_query(context, query, sort_by):
 
     """
     result = context.obj['opsgenie'].query_alerts(query)
-    sortedlist = sorted(result, key=itemgetter(sort_by))
     table_fields = ['message', 'tags', 'integration', 'createdAt']
+    if sort_by not in table_fields:
+        raise click.UsageError(
+            f"No column name found named: '{sort_by}'."
+        )
+    else:
+        sortedlist = sorted(result, key=itemgetter(sort_by))
     format_table = create_and_add_to_pretty_table(table_fields, sortedlist)
 
     output = format_table if len(format_table._rows) > 0 else 'No alerts found..'
@@ -283,7 +288,6 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
     else:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name}", limit)
-    sortedlist = sorted(result, key=itemgetter(sort_by))
 
     if more_info:
         table_fields = ['message', 'status', 'acknowledged',
@@ -291,6 +295,13 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
     else:
         table_fields = ['message', 'status', 'acknowledged', 'createdAt']
 
+    if sort_by not in table_fields:
+        raise click.UsageError(
+            f"No column name found named: '{sort_by}'."
+        )
+    else:
+        sortedlist = sorted(result, key=itemgetter(sort_by))
+
     if out_of_office_hours:
         sortedlist = [x for x in sortedlist  \
                         if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour >= 17 \
@@ -337,14 +348,16 @@ def alerts_get(context, id_):
 @click.option('--team-name', 'team_name', default=False)
 @click.option('--not-filtered', default=False, is_flag=True)
 @click.option('--out-of-office-hours', default=False, is_flag=True)
+@click.option('--last')
 @click.option('--limit', default=100)
 @click.pass_context
-def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit):
+def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit, last):
     """
     Function to show which alerts were noisy
 
     Args:
         team_name: shows the alerts for the team specified
+        last: retrieving alerts going back for x amount of time
 
     Returns:
         Table output with alerts for an Opsgenie team and the occurrence of the alerts
@@ -359,6 +372,9 @@ def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit):
             "Specify the teamname using --teamname."
         )
 
+    if last and limit == 100:
+        print(f'Note: You might need to increase limit, in order to see all alerts for the period.')
+
     if not_filtered:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
     else:
@@ -368,8 +384,20 @@ def alerts_count(context, team_name, not_filtered, out_of_office_hours, limit):
         result = [x for x in result  \
                         if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour >= 17 \
                         or (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour < 8]
+    if last:
+        if 'm' in last:
+            subtract_period = 'months'
+        if 'w' in last:
+            subtract_period = 'weeks'
+        if 'd' in last:
+            subtract_period = 'days'
+        subtract_value = int(re.sub(r'[mwd]', '', last))
+        args = {subtract_period:subtract_value}
+        subtracted_date = (pendulum.now().in_tz('Europe/Amsterdam')).subtract(**args)
+        result = [x for x in result  \
+                        if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam') >= subtracted_date]
 
-    dictionary = collections.Counter(item['message'] for item in result)
+    dictionary = collections.Counter((re.sub(r'(\n|\r)', '', item['message'])) for item in result)
     sorted_by_count = sorted(dictionary.items(), reverse=True, key=itemgetter(1))
     for alert in sorted_by_count:
         print(f"{alert[1]} - {alert[0]}")
@@ -1575,7 +1603,7 @@ def schedules_timeline(context, team_name, history, expand, interval, intervalun
         else:
             start_dt = pendulum.parse(item['startDate']).in_tz('Europe/Amsterdam')
             end_dt = pendulum.parse(item['endDate']).in_tz('Europe/Amsterdam')
-            format_table.add_row([item['recipient']['name'], start_dt.to_datetime_string(), end_dt.to_datetime_string()])
+            format_table.add_row([item['recipient']['name'], f'{start_dt.format("ddd")} {start_dt.to_datetime_string()}', f'{end_dt.format("ddd")} {end_dt.to_datetime_string()}'])
     print(format_table)
 
 
